camelot.camelot.model.memento.Memento

Package camelot :: Package camelot :: Package model :: Module memento :: Class Memento |
[hide private]
[frames] | no frames]

# Class Memento

source code

Keeps information on the previous state of objects, to keep track of changes and enable restore to that previous state

Nested Classes | [hide private]
| Admin

Class Variables | [hide private]
| model = `Field(Unicode(256), index= True, required= True)`
| primary_key = `Field(INT(), index= True, required= True)`
| creation_date = `Field(DateTime(), default= datetime.datetime.now)`
| person = `ManyToOne('Person', required= True, ondelete= 'restri`...``
| description = `property(lambda self: 'Change')`

Class Variable Details | [hide private]

  ### person Value:
      ManyToOne('Person', required= True, ondelete= 'restrict', onupdate= 'c
      ascade')